@@ -1,7 +1,7 @@
 # Standard library
 from typing import (
-    List,
     NamedTuple,
+    Tuple,
 )
 
 Frame = NamedTuple('Frame', [
@@ -12,8 +12,7 @@ Frame = NamedTuple('Frame', [
 ])
 
 DaemonResult = NamedTuple('DaemonResult', [
-    ('stack', List[Frame]),
-    ('stdout', str),
+    ('stack', Tuple[Frame, ...]),
 ])
 
 LoopSnapshot = NamedTuple('LoopSnapshot', [
